#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-D2fRAIkLs9K67oKNR10CMj
key:                  http-streams-0.8.9.9-D2fRAIkLs9K67oKNR10CMj
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  d54bb98435cb351316599c20dcbd7a6e
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-D2fRAIkLs9K67oKNR10CMj
depends:
    HsOpenSSL-0.11.7.10-72aBGaewYjbEhtZXYKzg7c
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    attoparsec-0.14.4-Jn9OdnAKkVz1hO2dwh0zwz
    attoparsec-aeson-2.2.0.1-JUXG5GfOroSJ8vLCYXBuz0 base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    blaze-builder-0.4.4.1-6b9visw8HKrC1WJWquHe2m bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2Yyf9IxnGFQLPP0jk4pg3Q directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-LB3FE2gvL3R82UcClQmf6M
    io-streams-1.5.2.2-h4AeGCmO0kLAw7dl36WEj mtl-2.3.1
    network-3.1.4.0-FBuTdTHZ29uBPcO3Y238RO
    network-uri-2.6.4.2-Fs1V3yFgC4iGyoDpGJIE7J
    openssl-streams-1.2.3.0-IyFIeGNDdnVINbVfVZcb7j text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

